.. _cexpensions:

======================
C Extensions
======================

Pulsar is shipped with a set of C extensions for speeding up performance and
provide additional functionalities.

* Redis encoder/decoder
* Websocket encoder/decoder
